@@ -4,12 +4,14 @@
 #----------------------------------------------------------------------------------------
 #----------------------------------------------------------------------------------------
 # extractAIC  needs MASS
-extractAIC.gamlss<-function (fit, scale, k = 2, ...) 
+extractAIC.gamlss<-function (fit, scale, k = 2, c = FALSE,  ...) 
 {
     if (is.gamlss(fit)) 
        {
         edf <- fit$df.fit
-        aic <- fit$G.dev + fit$df.fit * k
+          N <- fit$N
+        Cor <- if ((k == 2)&&(c==TRUE)) (2*edf*(edf+1))/(N-edf-1) else 0 
+        aic <- fit$G.dev + fit$df.fit * k + Cor
         return( c(edf, aic))
        }
     else stop(paste("this is not a gamlss object"))
@@ -21,10 +23,6 @@ extractAIC.gamlss<-function (fit, scale, k = 2, ...)
 #UseMethod("dropterm")
 #addterm <- function (object, ...) 
 #UseMethod("addterm")
-#----------------------------------------------------------------------------------------
-drop1.gamlss<-function(object, ...) gamlss:::dropterm.gamlss(object, test="Chisq", ...)
- add1.gamlss<-function(object, ...)  gamlss:::addterm.gamlss(object, test="Chisq", ...)
-#----------------------------------------------------------------------------------------
 # dropterm extractAIC  needs MASS
 dropterm.gamlss<-function (object, 
                            scope, 
@@ -64,7 +62,7 @@ dropterm.gamlss<-function (object,
     ns <- length(scope)
     ans <- matrix(nrow = ns + 1, ncol = 2, dimnames = list(c("<none>", 
         scope), c("df", "AIC")))
-    ans[1, ] <- extractAIC(object, scale, k = k, ...)
+    ans[1, ] <- extractAIC(object, scale, k = k,   ...)
     for (i in seq(ns)) 
       {
         tt <- scope[i]
@@ -78,7 +76,7 @@ dropterm.gamlss<-function (object,
                   cat("Model with term ", tt, "has failed \n")       
                   ans[i + 1, ] <- NA# extractAIC(object, scale, k = k, ...)          
                  }
-            else ans[i + 1, ] <- extractAIC(nfit, scale, k = k, ...)
+            else ans[i + 1, ] <- extractAIC(nfit, scale, k = k,   ...)
       }
     dfs <- ans[1, 1] - ans[, 1]
     dfs[1] <- NA
@@ -107,7 +105,7 @@ dropterm.gamlss<-function (object,
 }
 #----------------------------------------------------------------------------------------
 #  addterm
-addterm.gamlss<- function (object, 
+addterm.gamlss <- function (object, 
                            scope,
                            what = c("mu", "sigma", "nu", "tau"), 
                           scale = 0, 
@@ -136,7 +134,7 @@ addterm.gamlss<- function (object,
     ns <- length(scope)
     ans <- matrix(nrow = ns + 1, ncol = 2, dimnames = list(c("<none>", 
         scope), c("df", "AIC")))
-    ans[1, ] <- extractAIC(object, scale, k = k, ...)
+    ans[1, ] <- extractAIC(object, scale, k = k,   ...)
     for (i in seq(ns)) 
       {
         tt <- scope[i]
@@ -150,7 +148,7 @@ addterm.gamlss<- function (object,
                   cat("Model with term ", tt, "has failed \n")       
                   ans[i + 1, ] <- NA# extractAIC(object, scale, k = k, ...)          
                  }
-            else ans[i + 1, ] <- extractAIC(nfit, scale, k = k, ...)
+            else ans[i + 1, ] <- extractAIC(nfit, scale, k = k,  ...)
       }
     dfs <- ans[, 1] - ans[1, 1]
     dfs[1] <- NA
@@ -298,7 +296,7 @@ stepGAIC.VR <-function(object,
          n <- object[[nmm]]
     else n <- length(residuals(object))
      fit <- object
-    bAIC <- extractAIC(fit, scale, k = k, ...)
+    bAIC <- extractAIC(fit, scale, k = k,  ...)
      edf <- bAIC[1]
     bAIC <- bAIC[2]
     if (is.na(bAIC)) 
@@ -682,3 +680,7 @@ finalmodel <-eval(newcall)
 finalmodel 
 }
 #----------------------------------------------------------------------------------------
+#----------------------------------------------------------------------------------------
+drop1.gamlss<-function(object, ...) dropterm(object, test="Chisq", ...)
+ add1.gamlss<-function(object, ...)  addterm(object, test="Chisq", ...)
+#----------------------------------------------------------------------------------------
\ No newline at end of file
